pub struct DetectionParams {
pub min_area: f32,
pub text_threshold: f32,
}Expand description
Post-processing parameters for the text detection segmentation mask.
Fields
min_area: f32Minimum area of word bounding boxes returned from connected components.
text_threshold: f32Per-pixel score threshold for classifying a pixel as text.