pub struct NeuCodecEncoder;Expand description
NeuCodec encoder: converts a 16 kHz audio waveform to speech token IDs.
Note: The full NeuCodec encoder requires Wav2Vec2BertModel (~600 MB) as a semantic feature extractor. Encoder support is not yet implemented in this pure-Rust build.
For reference audio encoding, use the Python neucodec package:
from neucodec import NeuCodec
model = NeuCodec.from_pretrained("neuphonic/neucodec")
codes = model.encode_code(waveform) # → i32 arrayThen save the codes as a .npy file and pass via --ref-codes to the
synthesis examples.
Implementations
Sourceimpl NeuCodecEncoder
impl NeuCodecEncoder
Sourcepub fn new() -> Result<NeuCodecEncoder, Error>
pub fn new() -> Result<NeuCodecEncoder, Error>
Always returns an error — encoder not yet implemented.
Sourcepub fn load(_path: &Path) -> Result<NeuCodecEncoder, Error>
pub fn load(_path: &Path) -> Result<NeuCodecEncoder, Error>
Always returns an error — encoder not yet implemented.
Sourcepub fn encode_wav(&self, _path: &Path) -> Result<Vec<i32>, Error>
pub fn encode_wav(&self, _path: &Path) -> Result<Vec<i32>, Error>
Encode a WAV file to speech token IDs (not implemented).
Sourcepub fn backend_name(&self) -> &str
pub fn backend_name(&self) -> &str
Backend name.